@@ -133,6 +133,17 @@ class SemVer(s_types.Int):
         valu = s_version.fmtVersion(major, minor, patch)
         return valu
 
+loglevels = (
+    (10, 'debug'),
+    (20, 'info'),
+    (30, 'notice'),
+    (40, 'warning'),
+    (50, 'err'),
+    (60, 'crit'),
+    (70, 'alert'),
+    (80, 'emerg'),
+)
+
 class ItModule(s_module.CoreModule):
     async def initCoreModule(self):
         self.model.form('it:dev:str').onAdd(self._onFormItDevStr)
@@ -236,6 +247,10 @@ class ItModule(s_module.CoreModule):
                 ('it:host', ('guid', {}), {
                     'doc': 'A GUID that represents a host or system.'
                 }),
+                ('it:log:event', ('guid', {}), {
+                    'doc': 'A GUID representing an individual log event.',
+                    'interfaces': ('it:host:activity',),
+                }),
                 ('it:network', ('guid', {}), {
                     'doc': 'A GUID that represents a logical network.'
                 }),
@@ -497,6 +512,17 @@ class ItModule(s_module.CoreModule):
                         'doc': 'The org that operates the given host.',
                     }),
                 )),
+                ('it:log:event', {}, (
+                    ('mesg', ('str', {}), {
+                        'doc': 'The log messsage text.',
+                    }),
+                    ('severity', ('int', {'enums': loglevels}), {
+                        'doc': 'A log level integer that increases with severity.',
+                    }),
+                    ('data', ('data', {}), {
+                        'doc': 'A raw JSON record of the log event.',
+                    }),
+                )),
                 ('it:domain', {}, (
                     ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
                         'doc': 'The name of the domain.',
