@@ -13,21 +13,19 @@ class CryoServerTest(s_t_utils.SynTest):
 
         with self.getTestDir() as dirn, self.withSetLoggingMock() as mock:
 
-            outp = self.getTestOutp()
-
             argv = [dirn,
                     '--telepath', 'tcp://127.0.0.1:0/',
                     '--https', '0',
                     '--name', 'telecryo']
 
-            async with await s_cryo.CryoCell.initFromArgv(argv, outp=outp) as cryotank:
+            async with await s_cryo.CryoCell.initFromArgv(argv) as cryotank:
                 async with cryotank.getLocalProxy() as proxy:
                     await proxy.puts('foo', recs)
 
                 self.true(cryotank.dmon.shared.get('telecryo') is cryotank)
 
             # And data persists...
-            async with await s_cryo.CryoCell.initFromArgv(argv, outp=outp) as telecryo:
+            async with await s_cryo.CryoCell.initFromArgv(argv) as telecryo:
                 async with telecryo.getLocalProxy() as proxy:
                     precs = await s_t_utils.alist(proxy.slice('foo', 0, 100))
                     precs = [rec for offset, rec in precs]
