@@ -677,6 +677,12 @@ class HttpReflector(s_httpapi.Handler):
                     d[k].append(v.decode())
         resp['headers'] = dict(self.request.headers)
         resp['path'] = self.request.path
+
+        sleep = resp.get('params', {}).get('sleep')
+        if sleep:
+            sleep = int(sleep[0])
+            await asyncio.sleep(sleep)
+
         self.sendRestRetn(resp)
 
     async def post(self):
@@ -924,7 +930,7 @@ class SynTest(unittest.TestCase):
             mock.MagicMock: Yields a mock.MagikMock object.
         '''
         with mock.patch('synapse.common.setlogging',
-                        mock.MagicMock(return_value=None)) as patch:  # type: mock.MagicMock
+                        mock.MagicMock(return_value=dict())) as patch:  # type: mock.MagicMock
             yield patch
 
     def getMagicPromptLines(self, patch):
